@@ -138,6 +138,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def CreateScdnFailedLogTask(self, request):
+        """CreateScdnFailedLogTask 用于重试创建失败的事件日志任务
+
+        :param request: Request instance for CreateScdnFailedLogTask.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.CreateScdnFailedLogTaskRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.CreateScdnFailedLogTaskResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("CreateScdnFailedLogTask", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.CreateScdnFailedLogTaskResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def CreateScdnLogTask(self, request):
         """CreateScdnLogTask 用于创建事件日志任务
 
@@ -401,7 +429,7 @@ class CdnClient(AbstractClient):
 
 
     def DescribeCdnOriginIp(self, request):
-        """本接口（DescribeCdnOriginIp）用于查询 CDN 回源节点的IP信息。（注：使用此接口需开启对应白名单）
+        """本接口（DescribeCdnOriginIp）用于查询 CDN 回源节点的IP信息。（注：此接口即将下线，不再进行维护，请通过DescribeIpStatus 接口进行查询）
 
         :param request: Request instance for DescribeCdnOriginIp.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeCdnOriginIpRequest`
@@ -891,6 +919,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeScdnConfig(self, request):
+        """DescribeScdnConfig 用于查询指定 SCDN 加速域名的安全相关配置
+
+        :param request: Request instance for DescribeScdnConfig.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnConfigRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.DescribeScdnConfigResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeScdnConfig", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeScdnConfigResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeScdnTopData(self, request):
         """获取SCDN的Top数据
 
@@ -977,7 +1033,7 @@ class CdnClient(AbstractClient):
 
 
     def DisableCaches(self, request):
-        """DisableCaches 用于禁用 CDN 上指定 URL 的访问，禁用完成后，全网访问会直接返回 403。（接口尚在内测中，暂未全量开放使用）
+        """DisableCaches 用于禁用 CDN 上指定 URL 的访问，禁用完成后，中国境内访问会直接返回 403。（接口尚在内测中，暂未全量开放使用）
 
         :param request: Request instance for DisableCaches.
         :type request: :class:`tencentcloud.cdn.v20180606.models.DisableCachesRequest`
@@ -1228,6 +1284,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def ListScdnDomains(self, request):
+        """ListScdnDomains 用于查询 SCDN 安全加速域名列表，及域名基本配置信息
+
+        :param request: Request instance for ListScdnDomains.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.ListScdnDomainsRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.ListScdnDomainsResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("ListScdnDomains", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.ListScdnDomainsResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def ListScdnLogTasks(self, request):
         """ListScdnLogTasks 用于查询SCDN日志下载任务列表,以及展示下载任务基本信息
 
@@ -1463,6 +1547,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def StartScdnDomain(self, request):
+        """StartScdnDomain 用于开启域名的安全防护配置
+
+        :param request: Request instance for StartScdnDomain.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.StartScdnDomainRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.StartScdnDomainResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("StartScdnDomain", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.StartScdnDomainResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def StopCdnDomain(self, request):
         """StopCdnDomain 用于停止域名的加速服务。
         注意：停止加速服务后，访问至加速节点的请求将会直接返回 404。为避免对您的业务造成影响，请在停止加速服务前将解析切走。
@@ -1492,6 +1604,34 @@ class CdnClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def StopScdnDomain(self, request):
+        """StopScdnDomain 用于关闭域名的安全防护配置
+
+        :param request: Request instance for StopScdnDomain.
+        :type request: :class:`tencentcloud.cdn.v20180606.models.StopScdnDomainRequest`
+        :rtype: :class:`tencentcloud.cdn.v20180606.models.StopScdnDomainResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("StopScdnDomain", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.StopScdnDomainResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def UpdateDomainConfig(self, request):
         """UpdateDomainConfig 用于修改内容分发网络加速域名配置信息
         注意：如果需要更新复杂类型的配置项，必须传递整个对象的所有属性，未传递的属性将使用默认值，建议通过查询接口获取配置属性后，直接修改后传递给本接口。Https配置由于证书的特殊性，更新时不用传递证书和密钥字段。
